@@ -28,6 +28,8 @@
 #include <libxml/tree.h>
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 GType
 gupnp_xml_doc_get_type (void) G_GNUC_CONST;
 
@@ -78,4 +80,6 @@ GUPnPXMLDoc *
 gupnp_xml_doc_new_from_path             (const char     *path,
                                          GError        **error);
 
+G_END_DECLS
+
 #endif /* __GUPNP_XML_DOC_H__ */
