@@ -443,9 +443,6 @@ test_bgo_722696 (void)
 
 int
 main (int argc, char *argv[]) {
-#if !GLIB_CHECK_VERSION(2,35,0)
-    g_type_init ();
-#endif
     g_test_init (&argc, &argv, NULL);
     g_test_add_func ("/bugs/696762", test_bgo_696762);
     g_test_add_func ("/bugs/678701", test_bgo_678701);
